Learn R Programming

shinychat (version 0.3.0)

shinychat-package: shinychat: Chat UI Component for 'shiny'

Description

Provides a scrolling chat interface with multiline input, suitable for creating chatbot apps based on Large Language Models (LLMs). Designed to work particularly well with the 'ellmer' R package for calling LLMs.

Arguments

Author

Maintainer: Garrick Aden-Buie garrick@adenbuie.com (ORCID)

Authors:

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

See Also